# -*- coding: utf-8 -*-


#  Read in Montreal Bixi bike program data
# For each bike station find all the trips starting at that
# station and store where they end.
# Store in a Python dictionary with the end stations as a list.
# {station_id:[station_id_1, station_id_2]}

import glob


# Here's one way to make this program faster.  


# Get the station id's
# This function seems fast enough, ~300 microsec per call.
def get_station_ids(fname):
    ''' Read the stations_2018.csv
    file. The 1st column is what we need.'''
    stations = []
    with open(fname) as f:
        f.readline() # toss the header
        for line in f:
            line = line.split(',')
            stations.append(int(line[0]))
    return stations


def get_all_ends(station_ids, csv_files):
    ''' Get all the ends from all the files'''
    # Read each file ONCE. As each file is read process ALL of the
    # station ids.
    # Initialize the output dictionary with an empty list for
    # each station id
    out ={}
    for station in station_ids:
        out[station] =[]
    for csv in csv_files:
        with open(csv) as f:
            f.readline() # toss the header
            for line in f:
                line = line.split(',')
                station = int(line[1])
                # make sure the station is in the output dict
                if station in out:
                    out[station].append(int(line[3]))
    return out

if __name__ == '__main__':
    # 552 stations are loaded.
    station_ids = get_station_ids('bixi/Stations_2018.csv')
    ###  The runtime for this version is 4.8 seconds to 
    ###  read ALL of the data.
    ### How does the perfomance compare to the slow version?
    # Run with just a few stations to run the profiler
    # in the same way as before.
    csv_files = glob.glob('bixi/OD*csv')
    station_data = get_all_ends(station_ids[0:3],csv_files)
    # To run the whole dataset use all the station_ids
    #station_data = get_all_ends(station_ids,csv_files)
  
