# -*- coding: utf-8 -*-


#  Read in Montreal Bixi bike program data
# Data is from:  
# https://www.kaggle.com/jackywang529/bixi-montreal-bikeshare-data

# Line count per file:
#   OD_2018-07.csv - 953,032
#   OD_2018-08.csv - 956,791
#   OD_2018-09.csv - 797,521
#   Stations_2018.csv - 533

# For each bike station S find all the trips starting at 
# S and store where they end.
# Store in a Python dictionary with the end stations as a list.
# {station_id:[station_id_1, station_id_2]}
# Ex. rides from 6233 end at 6141, 6034, and 4001:
#  {6233: [6141,6034,4001]}
import glob

# Get the station id's
def get_station_ids(fname):
    ''' Read the stations_2018.csv
    file. The 1st column is what we need.'''
    stations = []
    with open(fname) as f:
        f.readline() # toss the header
        for line in f:
            # Could the extraction of this 1 number be faster?
            line = line.split(',')
            stations.append(int(line[0]))
    return stations

def get_station_ends(station_id, fname):
    ''' Build up the end station list for a 
        station_id from a .csv file. '''
    # file header: 
    #  start_date,start_station_code,end_date,end_station_code,duration_sec,is_member
    # column index 3 is what we want, the "end_station_code"
    ends = []
    with open(fname) as f:
        f.readline() # toss the header
        for line in f:
            line = line.split(',')
            if int(line[1]) == station_id:
                ends.append(line[3])
    return ends

def get_all_ends(station_ids, csv_files):
    ''' Get all the ends from all the files'''
    out = {}
    for station_id in station_ids:
        out[station_id] = []
        for csv in csv_files:
            ends = get_station_ends(station_id, csv)
            if len(ends) > 0:
                out[station_id] += ends
    return out

if __name__ == '__main__':
    # 552 stations are loaded.
    station_ids = get_station_ids('bixi/Stations_2018.csv')
    ###  The runtime is ~12 MINUTES.  How can we improve performance?
    ###  What's so slow?
    # Run with just a few station ids to run the profiler
    csv_files = glob.glob('bixi/OD*csv')
    station_data = get_all_ends(station_ids[0:3],csv_files)
    # full data set
    # station_data = get_all_ends(station_ids,csv_files)

  
