# -*- coding: utf-8 -*-
"""
Created on Thu Jan  2 13:16:35 2020

@author: bgregor
"""

import tqdm


def get_name(line):
    ''' Extract the "last,first" name from the line'''
    # the line is:  1,4,"last, first", ....etc...
    # note the , inside the double quotes. Split by commas
    # and then rejoin the name.
    tmp = line.split(',')[2:4]
    # tmp is ['"last', ' first"'].  Join into one string
    # then clean up the quotation marks.
    tmp = ','.join(tmp)
    tmp = tmp.replace('"','')
    return tmp

def read_file(filename):
    ''' Read the names of 
        the file into a list'''
    with open(filename,'r') as f:
        # Read the header line and ignore it.
        f.readline()
        # Read in everything else
        # to a list. Lowercase them
        # all for consistency
        return [get_name(x).lower() for x in f.readlines()]
    

def compare_finishers(names1, names2):
    ''' names1 and names2 are lists
        of names. 
        Return a list of all names 
        that are in both lists.'''
    both = []
    for n in names1:
        if n in names2:
            both.append(n)
    return both

if __name__=='__main__':
    names_2015 = read_file('marathon_results_2015.csv')
    names_2017 = read_file('marathon_results_2017.csv')
    print('%s runners in 2015' % len(names_2015))
    print('%s runners in 2017' % len(names_2017))

    both = compare_finishers(names_2015,names_2017)
    
    print('%s runners completed both marathons.' % len(both))
    
    

            