# -*- coding: utf-8 -*-
"""
Created on Thu Jan  2 13:16:35 2020

@author: bgregor
"""

import tqdm

def get_name(line):
    ''' Extract the "last,first" name from the line'''
    # the line is:  1,4,"last, first", ....etc...
    # note the , inside the double quotes. Split by commas
    # and then rejoin the name.
    tmp = line.split(',')[2:4]
    # tmp is ['"last', ' first"'].  Join into one string
    # then clean up the quotation marks.
    tmp = ','.join(tmp)
    tmp = tmp.replace('"','')
    return tmp

def read_file(filename):
    ''' Read the names of 
        the file into a set'''
    with open(filename,'r') as f:
        # Read the header line and ignore it.
        f.readline()
        # Read in everything else
        # to a set.
        names = set()
        for line in f.readlines():
            tmp = get_name(line)
            names.add(tmp.lower())
        return names
    

def compare_lists(names1, names2):
    ''' names1 and names2 are sets
        of names. 
        Return a set of all names 
        that are in both sets.'''
    # this is just a set intersection
    return names1.intersection(names2)

if __name__=='__main__':
    names_2015 = read_file('marathon_results_2015.csv')
    names_2017 = read_file('marathon_results_2017.csv')
    print('%s runners in 2015' % len(names_2015))
    print('%s runners in 2017' % len(names_2017))
    
    both = compare_lists(names_2015,names_2017)
    
    print('%s runners completed both marathons.' % len(both))
    
    

            