# -*- coding: utf-8 -*-
"""
Created on Thu Jan  2 14:25:43 2020

Some examples of numpy functions

@author: bgregor
"""

import numpy as np
import time
from matplotlib import pyplot as plt
import tqdm

def rand_ndarray_append(N):
    ''' return an ndarray of N randoms numbers'''
    # This is implemented using numpy.append()
    rans=np.zeros(0)
    for i in range(N):
        rans=np.append(rans,np.random.random())
    return rans

def rand_ndarray_pre_alloc(N):
    ''' return an ndarray of N randoms numbers'''
    # This is implemented by pre-allocating a 
    # numpy array and then filling it.
    rans=np.ndarray(N) # no initialization
    for i in range(N):
        rans[i]=np.random.random()
    return rans


def rand_ndarray_list_conv(N):
    ''' return an ndarray of N randoms numbers'''
    # This is implemented by building a list
    # and then converting it to an ndarray
    rans=[]
    for i in range(N):
        rans.append(np.random.random())
    return np.asarray(rans)

def rand_ndarray_library(N):
    ''' return an ndarray of N randoms numbers'''
    # np.random.random() can allocate the ndarray and
    # fill it all in a single call...
    return np.random.random(N)

def plot_append(N):
    ''' create a time plot for numpy.append()'''
    elapsed=[]
    nums=np.zeros(1000000) # intial size
    block = np.zeros(250000) # block size to add
    for i in tqdm.tqdm(range(N)):
        start = time.perf_counter()
        nums = np.append(nums,block)
        elapsed.append(time.perf_counter() - start)
    plt.plot(range(N),elapsed)
    plt.xlabel('N elements')
    plt.ylabel('time (sec)')
    plt.title('Time to append 250k elements to N elements')
    plt.show()
    
# Run using the Spyder profiler
if __name__=='__main__':
    N=10000
    rand_ndarray_append(N)
    rand_ndarray_pre_alloc(N)
    rand_ndarray_list_conv(N)
    rand_ndarray_library(N)
    # After trying the profiling 
    # uncomment these lines and do a plot
    # of the time to do the append with 
    # growing N.
    #n_blocks=150
    #plot_append(n_blocks)