# -*- coding: utf-8 -*-
"""
Created on Tue Oct  1 12:56:11 2019


An example for use with basic timing and profiling.


@author: bgregor
"""
import numpy as np

# This is computing the multiplication of a matrix (2D table)
# of numbers by a constant value where every element of the
# matrix is multiplied by the value.  The result of the 
# multiplication overwrites the original matrix.

#  Ex. say x=[ 1 2
#              3 4]
#
#  compute:  x = A * x where A is a number
#
#  2 * x = [ 2 4
#            6 8]
#  and then assign that over the original value of x.

# Pick a number to set the size of the matrix
mat_size = 2000
# Let's just multiply by 2.
scaling_value = 2.0

def row_by_row(A,mat):
    ''' compute mat = A*mat row-by-row '''
    rows = mat.shape[0]
    for i in range(rows):
        mat[i,:] = A * mat[i,:] 
    return mat


def col_by_col(A,mat):
    ''' compute mat = A*mat col_by_col '''
    cols = mat.shape[1]
    for i in range(cols):
        mat[:,i] = A * mat[:,i]  
    return mat

def built_in(A,mat):
    ''' A*mat using built-in element-by-element'''
    return A * mat


if __name__=='__main__':
    # Create the matrix.
    mat = np.ones([mat_size,mat_size])
    # Run each function.
    mat = row_by_row(scaling_value, mat)
    mat = col_by_col(scaling_value, mat)
    mat = built_in(scaling_value, mat)


