# -*- coding: utf-8 -*-
"""
Created on Tue Oct  1 12:56:11 2019

MANUAL timing of function calls.

@author: bgregor
"""
import numpy as np

import time


# Pick a number to set the size of the matrix
mat_size = 100
# Let's just multiply by 2.
scaling_value = 2.0


def row_by_row(A,mat):
    ''' compute mat = A*mat row-by-row '''
    rows = mat.shape[0]
    for i in range(rows):
        mat[i,:] = A * mat[i,:]  
    return mat

def col_by_col(A,mat):
    ''' compute mat = A*mat col_by_col '''
    cols = mat.shape[1]
    for i in range(cols):
        mat[:,i] =  A * mat[:,i]  
    return mat

def built_in(A,mat):
    ''' A*mat using built-in element-by-element'''
    return A * mat  


if __name__=='__main__':
    # Create the matrix.
    mat = np.ones([mat_size,mat_size])

    # Run each function.
    # Get a starting time.
    start_t = time.perf_counter()
    mat = row_by_row(scaling_value, mat)
    # Function call is done, get an ending time
    end_t = time.perf_counter()
    # The end_t - start_t difference is the execution time
    print('row_by_row: %s sec' % (end_t - start_t))

    # and laboriously repeat...
    start_t = time.perf_counter()
    mat = col_by_col(scaling_value, mat)
    end_t = time.perf_counter()
    print('col_by_col: %s sec' % (end_t - start_t))
    
    start_t = time.perf_counter()
    mat = built_in(scaling_value, mat)
    end_t = time.perf_counter()
    print('built_in: %s sec' % (end_t - start_t))
 


